==> projectz-1.1.2.tgz: package/es2015/bin.js <==
'use strict';

var _caterpillar = require('caterpillar');

var _caterpillarFilter = require('caterpillar-filter');

var _caterpillarHuman = require('caterpillar-human');

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _package = require('../package.json');

var _index = require('./index');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Prepare our logging configuration


// Import our package data for versioning
/* @flow */
// Projectz CLI

// Import caterpillar [Caterpillar](https://github.com/bevry/caterpillar) for logging
var LOG_LEVEL_INFO = 6;

// Import out projectz utility


// Import [Commander](https://github.com/visionmedia/commander.js/) for command and option parsing

var LOG_LEVEL_DEBUG = 7;
var EXIT_ERROR_CODE = 1;
var level = process.argv.indexOf('-d') === -1 ? LOG_LEVEL_INFO : LOG_LEVEL_DEBUG;

// Setup our logging
var logger = new _caterpillar.Logger({ level: level });
var filter = new _caterpillarFilter.Filter();
var human = new _caterpillarHuman.Human();

// Pipe logger output to filter, then filter output to stdout
logger.pipe(filter).pipe(human).pipe(process.stdout);

// Extract out version out of our package and apply it to commander
_commander2.default.version(_package.version);

// Add our cwd customisation
_commander2.default.option('-p, --path [value]', 'Path to the project that you wish to work with, defaults to the current working directory');
_commander2.default.option('-d', 'Outputs verbose logging.');

// Add the compile command that will create a new projectz instance and compile the project
_commander2.default.command('compile').description('Compile our project').action(function () {
	// Create our new project and use our caterpillar logger instance for the logging
	logger.log('info', 'Initialising project');
	var project = _index.Projectz.create({
		log: logger.log.bind(logger),
		cwd: _commander2.default.path || null
	});
	logger.log('info', 'Initialised project');

	// Load the the files for the new project
	logger.log('info', 'Loading changes');
	project.load(function (err) {
		if (err) {
			logger.log('err', err.stack);
			process.exit(EXIT_ERROR_CODE);
		}
		logger.log('info', 'Loaded changes');

		// And apply the changes
		project.save(function (err) {
			if (err) {
				logger.log('err', err.stack);
				process.exit(EXIT_ERROR_CODE);
			}
			logger.log('info', 'Completed successfully');
		});
	});
});

// Start the commands
_commander2.default.parse(process.argv);

==> projectz-1.1.5.tgz: package/es2015/bin.js <==
'use strict';

var _caterpillar = require('caterpillar');

var _caterpillarFilter = require('caterpillar-filter');

var _caterpillarFilter2 = _interopRequireDefault(_caterpillarFilter);

var _caterpillarHuman = require('caterpillar-human');

var _caterpillarHuman2 = _interopRequireDefault(_caterpillarHuman);

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _package = require('../package.json');

var _index = require('./index');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Prepare our logging configuration


// Import our package data for versioning
/* @flow */
// Projectz CLI

// Import caterpillar [Caterpillar](https://github.com/bevry/caterpillar) for logging
var LOG_LEVEL_INFO = 6;

// Import out projectz utility


// Import [Commander](https://github.com/visionmedia/commander.js/) for command and option parsing

var LOG_LEVEL_DEBUG = 7;
var EXIT_ERROR_CODE = 1;
var level = process.argv.indexOf('-d') === -1 ? LOG_LEVEL_INFO : LOG_LEVEL_DEBUG;

// Setup our logging
var logger = new _caterpillar.Logger({ level: level });
var filter = new _caterpillarFilter2.default();
var human = new _caterpillarHuman2.default();

// Pipe logger output to filter, then filter output to stdout
logger.pipe(filter).pipe(human).pipe(process.stdout);

// Extract out version out of our package and apply it to commander
_commander2.default.version(_package.version);

// Add our cwd customisation
_commander2.default.option('-p, --path [value]', 'Path to the project that you wish to work with, defaults to the current working directory');
_commander2.default.option('-d', 'Outputs verbose logging.');

// Add the compile command that will create a new projectz instance and compile the project
_commander2.default.command('compile').description('Compile our project').action(function () {
	// Create our new project and use our caterpillar logger instance for the logging
	logger.log('info', 'Initialising project');
	var project = _index.Projectz.create({
		log: logger.log.bind(logger),
		cwd: _commander2.default.path || null
	});
	logger.log('info', 'Initialised project');

	// Load the the files for the new project
	logger.log('info', 'Loading changes');
	project.load(function (err) {
		if (err) {
			logger.log('err', err.stack);
			process.exit(EXIT_ERROR_CODE);
		}
		logger.log('info', 'Loaded changes');

		// And apply the changes
		project.save(function (err) {
			if (err) {
				logger.log('err', err.stack);
				process.exit(EXIT_ERROR_CODE);
			}
			logger.log('info', 'Completed successfully');
		});
	});
});

// Start the commands
_commander2.default.parse(process.argv);
